@@ -1,5 +1,7 @@
 #!/usr/bin/perl -w
 #
+#    vi: set ts=2 sw=2 noai ic showmode showmatch:  
+#
 #    Copyright (C) 1998, Dj Padzensky <djpadz@padz.net>
 #    Copyright (C) 1998, 1999 Linas Vepstas <linas@linas.org>
 #    Copyright (C) 2000, Yannick LE NY <y-le-ny@ifrance.com>
@@ -46,12 +48,13 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.62'; # VERSION
+our $VERSION = '1.65'; # VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
     CurrencyFreaks
     ECB
+    FinanceAPI
     Fixer
     OpenExchange
     YahooJSON
@@ -71,19 +74,17 @@ our $VERSION = '1.62'; # VERSION
     Comdirect
     Consorsbank
     Currencies
-    DWS
     Deka
-    FTfunds
+    FinanceAPI
     Finanzpartner
     Fondsweb
     Fool
+    FTfunds
     GoldMoney
     GoogleWeb
     HU
-    IEXCloud
     IndiaMutual
     MarketWatch
-    MorningstarAU
     MorningstarCH
     MorningstarJP
     MorningstarUK
@@ -604,14 +605,20 @@ sub fetch {
     return;
   }
 
-  # Temporary Counting - not concerned about return code
-  # my $COUNT_URL =
-  #   'http://www.panix.com/~hd-fxsts/finance-quote.html?' . $method;
-  # my $count_ua = LWP::UserAgent->new(timeout => 10);
-  # my $count_response = $count_ua->head($COUNT_URL);
+  {
+    no strict 'vars';
+    our $VERSION = '0.00' unless defined $VERSION;
+    unless ($ENV{"FQ_NOCOUNT"}) {
+      # Temporary Counting - not concerned about return code
+      my $COUNT_URL =
+        'http://www.panix.com/~hd-fxsts/finance-quote.html?' . $VERSION . '&' . $method;
+      my $count_ua = LWP::UserAgent->new(timeout => 10);
+      my $count_response = $count_ua->head($COUNT_URL);
 
-  # ### COUNT_URL: $COUNT_URL
-  # ### Code: $count_response->code
+      ### COUNT_URL: $COUNT_URL
+      ### Code: $count_response->code
+    }
+  }
 
   # Failover code.  This steps through all available methods while
   # we still have failed stocks to look-up.  This loop only
@@ -783,7 +790,7 @@ sub store_date
       $year += 2000 if $year < 100;
       $year_specified = 1;
 
-      ### format: printf "usdate %s -> Day %d, Month %s, Year %d\n", $piecesref->{usdate}, $day, $month, $year
+      ### format: printf STDERR "usdate %s -> Day %d, Month %s, Year %d\n", $piecesref->{usdate}, $day, $month, $year
     }
 
     if ((defined $piecesref->{eurodate}) && ($piecesref->{eurodate})) {
@@ -791,7 +798,7 @@ sub store_date
       $year += 2000 if $year < 100;
       $year_specified = 1;
 
-      ### format: printf "eurodate %s -> Day %d, Month %s, Year %d\n", $piecesref->{eurodate}, $day, $month, $year
+      ### format: printf STDERR "eurodate %s -> Day %d, Month %s, Year %d\n", $piecesref->{eurodate}, $day, $month, $year
     }
 
     if (defined ($piecesref->{year})) {
@@ -817,7 +824,7 @@ sub store_date
     $month = $mnames{lc(substr($month,0,3))} if ($month =~ /\D/);
     $year-- if (($year_specified == 0) && ($this_month < $month));
 
-    ### format: printf "Final Year-Month-Day -> %04d-%02d-%02d\n", $year, $month, $day
+    ### format: printf STDERR "Final Year-Month-Day -> %04d-%02d-%02d\n", $year, $month, $day
 
     $inforef->{$symbol, "date"} =  sprintf "%02d/%02d/%04d", $month, $day, $year;
     $inforef->{$symbol, "isodate"} = sprintf "%04d-%02d-%02d", $year, $month, $day;
@@ -1269,7 +1276,6 @@ methods.
     my $q = Finance::Quote->new(timeout => 30)
     my $q = Finance::Quote->new('YahooJSON', fetch_currency => 'EUR')
     my $q = Finance::Quote->new('alphavantage' => {API_KEY => '...'})
-    my $q = Finance::Quote->new('IEXCloud', 'iexcloud' => {API_KEY => '...'});
     my $q = Finance::Quote->new(currency_rates => {order => ['ECB', 'Fixer'], 'fixer' => {API_KEY => '...'}});
 
 Finance::Quote modules access a wide range of sources to provide quotes.  A
@@ -1618,6 +1624,10 @@ Finance::Quote respects all environment that your installed version of
 LWP::UserAgent respects.  Most importantly, it respects the http_proxy
 environment variable.
 
+=head1 USAGE COUNTER
+
+A simple usage counter has been enabled. Other than the user's IP address, Finance::Quote version, and which method was used, no other data is collected. To opt out of your usage being counted, set the environment variable "FQ_NOCOUNT".
+
 =head1 BUGS
 
 The caller cannot control the fetch failover order.
@@ -1651,19 +1661,32 @@ Please refer to the sub-modules for further information.
 
 =head1 AUTHORS
 
-  Dj Padzensky <djpadz@padz.net>, PadzNet, Inc.
-  Linas Vepstas <linas@linas.org>
-  Yannick LE NY <y-le-ny@ifrance.com>
-  Paul Fenwick <pjf@cpan.org>
-  Brent Neal <brentn@users.sourceforge.net>
-  Volker Stuerzl <volker.stuerzl@gmx.de>
-  Keith Refson <Keith.Refson#earth.ox.ac.uk>
-  Rob Sessink <rob_ses@users.sourceforge.net>
-  Leigh Wedding <leigh.wedding@telstra.com>
-  Tobias Vancura <tvancura@altavista.net>
-  James Treacy <treacy@debian.org>
-  Bradley Dean <bjdean@bjdean.id.au>
+The following list are those contributors with 5 or more commits in the
+GitHub repository.
+Please see the Git log for all the authors who have helped with
+Finance::Quote.
+
   Erik Colson <eco@ecocode.net>
+  Bruce Schuck <bschuck@asgard-systems.com>
+  Paul Fenwick <pjf@perltraining.com.au>
+  Vincent Lucarelli <vincent.lucarelli@gmail.com>
+  David Hampton <hampton-sf@rainbolthampton.net>
+  jvolkening <jdv@base2bio.com>
+  Pawel Konieczny <konieczp@zonnet.nl>
+  Mike Alexander <mta@umich.edu>
+  AndreJ <Andre-J@users.noreply.github.com>
+  Vinay S Shastry <vinayshastry@gmail.com>
+  Bradley Dean <bjdean@bjdean.id.au>
+  Brent Neal <brent@reindeergraphics.com>
+  Jacinta Richardson <jarich@perltraining.com.au>
+  e-dorigatti <emilio.dorigatti@gmail.com>
+  goodvibes2 <goodchris96@gmail.com>
+  Paul Howarth <paul@city-fan.org>
+  Sam Morris <sam@robots.org.uk>
+  Linas Vepstas <linas@linas.org>
+  Rajan Vaswani <111571283+bgr22112@users.noreply.github.com>
+  Hiranya Samarasekera <hiranyas@gmail.com>
+  Manuel Friedli <manuel@fritteli.ch>
 
 The Finance::Quote home page can be found at
 http://finance-quote.sourceforge.net/
@@ -1679,6 +1702,7 @@ http://www.gnucash.org/
   Finance::Quote::CurrencyRates::AlphaVantage,
   Finance::Quote::CurrencyRates::CurrencyFreaks,
   Finance::Quote::CurrencyRates::ECB,
+  Finance::Quote::CurrencyRates::FinanceAPI,
   Finance::Quote::CurrencyRates::Fixer,
   Finance::Quote::CurrencyRates::OpenExchange,
   Finance::Quote::CurrencyRates::YahooJSON,
@@ -1694,19 +1718,17 @@ http://www.gnucash.org/
   Finance::Quote::Comdirect,
   Finance::Quote::Consorsbank,
   Finance::Quote::Currencies,
-  Finance::Quote::DWS,
   Finance::Quote::Deka,
-  Finance::Quote::FTfunds,
+  Finance::Quote::FinanceAPI,
   Finance::Quote::Finanzpartner,
   Finance::Quote::Fondsweb,
   Finance::Quote::Fool,
+  Finance::Quote::FTfunds,
   Finance::Quote::GoldMoney,
   Finance::Quote::GoogleWeb,
   Finance::Quote::HU,
-  Finance::Quote::IEXCloud,
   Finance::Quote::IndiaMutual,
   Finance::Quote::MarketWatch,
-  Finance::Quote::MorningstarAU,
   Finance::Quote::MorningstarCH,
   Finance::Quote::MorningstarJP,
   Finance::Quote::MorningstarUK,
@@ -1735,4 +1757,10 @@ Please read it if you are interested in adding extra methods to this package.
 The latest hacker's guide can also be found on GitHub at
 https://github.com/finance-quote/finance-quote/blob/master/Documentation/Hackers-Guide
 
+=head1 DONATIONS
+
+While the contributors to Finance::Quote are happy to volunteer their time and resources on this project, donations are helpful and great way to say thank you. So far the only real cost to the team is domain registration for finance-quote.org. However, some operating systems and hardware upgrades do have a cost. Access to the latest or current environments is needed for development and testing. Upgrades to the latest MS Windows often includes a cost, and recently Apple's move to ARM/M1/M2 CPUs has stifled some contributors' ability to assist. With that in mind, you can send donations to the email address donations@finance-quote.org through PayPal. If it's for a particular contributor, please indicate in a note while submitting the donation through PayPal.
+
+Additionally, Bitcoin donations can be received at 37Bg4EMAp575j4iL9jHv1ZhDgiropU38jY.
+
 =cut
